/* STRINGS.H -- LonBuilder Protocol Analyzer log file interpretation strings.
 * Copyright (c) 1993 by Echelon Corporation.
 * All Rights Reserved.
 *
 * Date last modified: 3/25/93
 *
 * Enumeration literal and text strings for packet monitor log dump.
 * First column is for brief mode, second column for verbose mode.
 */

enum strs {
    ack, akd, alt, apm, aut, bse, bts, cha, cod, crc,
    cre, dbc, dbl, dgr, did, dir, dsb, dsn, exm, fom,
    frs, grm, grp, hwe, iat, irl, ist, itt, msd, ndr, nid,
    nmr, nul, nvs, nwv, pnm, pri, prv, psz, ptp, rak,
    rem, rep, req, rml, rmr, rsp, rwa, sep, srs, ssn,
    toe, trn, uak, unk, unr, num, tim, spc };

const char * const strings[ ][ 2 ] = {

    { "ACK ",       "Acknowledgement\n"                 },
    { "AKD ",       "Acknowledged "                     },
    { "ALT:%s ",    "Alternate path\t\t%s\n"            },
    { ":APM ",      " - Application Message\n"          },
    { "AUT:%s ",    "Authentication\t\t%s\n"            },
    { "BSE ",       "*** Bitsync error\n"               },
    { "BTS:%u ",    "Broadcast to subnet\t%u\n"         },
    { "CHA:",       "Challenge\nRandom bytes\t\t"       },
    { "COD:%2.2x",  "Message code\t\t0x%2.2x"           },
    { "CRC:%4.4x ", "Packet CRC\t\t%4.4x\n"             },
    { "CRE ",       "*** CRC error\n"                   },
    { "DBC:%d ",    "Data byte count\t\t%d\n"           },
    { "DBL:%u ",    "Delta backlog\t\t%u\n"             },
    { "DGR:%u ",    "Destination group\t%u\n"           },
    { "DID:",       "Domain ID\t\t"                     },
    { "DIR:%s ",    "Direction\t\t%s\n"                 },
    { "DSB:%u ",    "Destination subnet\t%u\n"          },
    { "DSN:%u,%u ", "Dest subnet, node\t%u, %u\n"       },
    { "EXM ",       "explicit message\n"                },
    { ":FOM ",      " - Foreign Message\n"              },
    { "FRS:%s ",    "or Failed Response to\t%s\n"       },
    { "GRM:%u,%u ", "Group, member\t\t%u, %u\n"         },
    { "GRP:%u ",    "Group\t\t%u\n"                     },
    { "HWE",        "*** Development system hardware error\n" },
    { "IAT",        "*** Invalid AuthPDU type\n"        },
    { "IRL",        "*** Invalid reminder list length\n"},
    { "IST",        "*** Invalid SPDU type\n"           },
    { "ITT",        "*** Invalid TPDU type\n"           },
    { "MSD:",       "Message data\t\t"                  },
    { "NDR:%s ",    "Network diagnostic\t%s Request\n"  },
    { "NID ",       "Neuron ID\t\t"                     },
    { "NMR:%s ",    "Network management\t%s Request\n"  },
    { "NUL",        "(null)"                            },
    { "NVS:%2.2x%2.2x ", "Net variable selector\t%2.2x%2.2x\n" },
    { "NWV ",       "network variable\n"                },
    { "PNM:%u ",    "Packet number\t\t%u\n"             },
    { "PRI:%s ",    "Priority\t\t%s\n"                  },
    { "PRV:%u ",    "Protocol version\t%u\n"            },
    { "PSZ:%u ",    "Packet size\t\t%u\n"               },
    { "\nPTP:",     "Packet type\t\t"                   },
    { "RAK ",       "Reminder for acknowledgment\n"     },
    { "REM ",       "Reminder for response\n"           },
    { "REP:",       "Reply\nEncrypted bytes\t\t"        },
    { "REQ ",       "Request "                          },
    { "RML:",       "Reminder list\t\t"                 },
    { "RMR ",       "Reminder with request "            },
    { "RSP ",       "Response "                         },
    { "RWA ",       "Reminder with ackd "               },
    { "\n",         "-------------------------------------------------------\n" }, /* sep */
    { "SRS:%s ",    "or Success Response to\t%s\n"      },
    { "SSN:%u,%u ", "Source subnet, node\t%u, %u\n"     },
    { "TOE ",       "*** Timeout error\n"               },
    { "TRN:%u ",    "Transaction\t\t%u\n"               },
    { "UAK ",       "Unacknowledged "                   },
    { "UNK ",       "*** Unknown error\n"               },
    { "UNR ",       "Unacknowledged/repeated "          },
    { "%2.2x",      "%2.2x "                            },       /* num */
    { "TIM:",       "Time\t\t\t"                        },
    { " ",          "\n"                                }        /* spc */
};

const char * NM_msg_names[ ][ 2 ] = {
    { "x60",    "NM_0x60"               },
    { "QID",    "NM_query_id"           },
    { "RTQ",    "NM_respond_to_query"   },
    { "UPD",    "NM_update_domain"      },
    { "LVD",    "NM_leave_domain"       },
    { "UPK",    "NM_update_key"         },
    { "UPA",    "NM_update_addr"        },
    { "QAD",    "NM_query_addr"         },
    { "QNV",    "NM_query_nv_cnfg"      },
    { "UPG"     "NM_update_group_addr"  },
    { "QDM",    "NM_query_domain"       },
    { "UNV",    "NM_update_nv_cnfg"     },
    { "SNM",    "NM_set_node_mode"      },
    { "RDM",    "NM_read_memory"        },
    { "WRM",    "NM_write_memory"       },
    { "CSR",    "NM_checksum_recalc"    },
    { "WNK",    "NM_wink"               },
    { "MRF",    "NM_memory_refresh"     },
    { "QSN",    "NM_query_SNVT"         },
    { "NVF",    "NM_nv_fetch"           },
    { "SRM",    "NM_set_rtr_mode"       },
    { "RTC",    "NM_rtr_table_clear"    },
    { "RTD",    "NM_rtr_table_dwnld"    },
    { "RGF",    "NM_rtr_group_fwd"      },
    { "RSF",    "NM_rtr_subnet_fwd"     },
    { "RGN",    "NM_rtr_group_nofwd"    },
    { "RSN",    "NM_rtr_subnet_nofwd"   },
    { "RTR",    "NM_rtr_table_report"   },
    { "QRS",    "NM_query_rtr_status"   },
    { "x7D",    "NM_0x7D"               },
    { "FSE",    "NM_rtr_far_side_esc"   },
    { "SVP",    "NM_service_pin"        }
};

const char * ND_msg_names[ ][ 2 ] = {
    { "x50",    "ND_50"             },
    { "QNS",    "ND_query_status"   },
    { "PRX",    "ND_proxy"          },
    { "CNS",    "ND_clear_status"   },
    { "QXS",    "ND_query_xcvr"     },
    { "x55",    "ND_55"             },
    { "x56",    "ND_56"             },
    { "x57",    "ND_57"             }
};
